pub enum UnknownHandling {
Error,
Permit,
}Expand description
How to handle unknown opcode bytes encountered during disassembly.
Variants
Error
Surface an error as soon as an unknown opcode is encountered.
Permit
Emit an Unknown instruction and continue disassembling subsequent bytes.