NefError

Enum NefError 

#[non_exhaustive]
pub enum NefError {
Show 18 variants TooShort, InvalidMagic { expected: [u8; 4], actual: [u8; 4], }, ChecksumMismatch { expected: u32, calculated: u32, }, TrailingData { extra: usize, }, InvalidCompiler, ReservedByteNonZero { offset: usize, value: u8, }, ReservedWordNonZero { offset: usize, value: u16, }, UnexpectedEof { offset: usize, }, InvalidMethodToken { index: usize, }, IntegerOverflow { offset: usize, }, InvalidUtf8String { offset: usize, }, EmptyScript, SourceTooLong { length: usize, max: usize, }, TooManyMethodTokens { count: usize, max: usize, }, ScriptTooLarge { length: usize, max: usize, }, MethodNameInvalid { name: String, }, CallFlagsInvalid { flags: u8, allowed: u8, }, FileTooLarge { size: u64, max: u64, },
}
Errors returned while parsing NEF containers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TooShort

File too short to contain a NEF header and checksum.



InvalidMagic

Magic bytes at the start of the file did not match the NEF format.

Fields

expected: [u8; 4]

Expected magic sequence.

actual: [u8; 4]

Actual bytes found in the input.



ChecksumMismatch

Checksum mismatch between the stored and calculated values.

Fields

expected: u32

Checksum stored in the NEF file.

calculated: u32

Checksum calculated from the payload.



TrailingData

Trailing bytes were present after the checksum.

Fields

extra: usize

Number of extra bytes after the checksum.



InvalidCompiler

The compiler field contained invalid UTF-8.



ReservedByteNonZero

Reserved byte fields must be zero according to the NEF spec.

Fields

offset: usize

Byte offset of the reserved field.

value: u8

Non-zero value that was found.



ReservedWordNonZero

Reserved word fields must be zero according to the NEF spec.

Fields

offset: usize

Byte offset of the reserved field.

value: u16

Non-zero value that was found.



UnexpectedEof

Input ended unexpectedly while parsing.

Fields

offset: usize

Byte offset where parsing expected more data.



InvalidMethodToken

A method token entry was malformed.

Fields

index: usize

Index of the method token entry.



IntegerOverflow

A variable-length integer exceeded the supported range.

Fields

offset: usize

Offset where the oversized integer was read.



InvalidUtf8String

A variable-length string contained invalid UTF-8.

Fields

offset: usize

Offset where the invalid string was read.



EmptyScript

Script section cannot be empty.



SourceTooLong

Source string exceeded the maximum supported length.

Fields

length: usize

Actual string length.

max: usize

Maximum allowed length.



TooManyMethodTokens

Method token count exceeded the maximum supported value.

Fields

count: usize

Actual method token count.

max: usize

Maximum allowed method token count.



ScriptTooLarge

Script section exceeded the maximum supported size.

Fields

length: usize

Actual script length in bytes.

max: usize

Maximum allowed script length.



MethodNameInvalid

Method token name contained disallowed characters.

Fields

name: String

The method name that was rejected.



CallFlagsInvalid

Call flags contained bits outside the allowed set.

Fields

flags: u8

The unsupported flags value.

allowed: u8

Mask of allowed flag bits.



FileTooLarge

Input file exceeded the maximum supported size.

Fields

size: u64

Actual file size in bytes.

max: u64

Maximum allowed file size.