#[non_exhaustive]pub enum CallTarget {
Internal {
method: MethodRef,
},
MethodToken {
index: u16,
hash_le: String,
hash_be: String,
method: String,
parameters_count: u16,
has_return_value: bool,
call_flags: u8,
},
Syscall {
hash: u32,
name: Option<String>,
returns_value: bool,
},
Indirect {
opcode: String,
operand: Option<u16>,
},
UnresolvedInternal {
target: isize,
},
}Expand description
A resolved call target extracted from the instruction stream.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Internal
Direct call into the same script (CALL/CALL_L).
MethodToken
Call to an entry in the NEF method-token table (CALLT).
Fields
Syscall
System call (SYSCALL).
Fields
Indirect
Indirect call (e.g., CALLA) where the destination cannot be resolved statically.
Fields
UnresolvedInternal
A CALL/CALL_L target that could not be resolved to a valid offset.